Learn R Programming

doseminer (version 0.1.2)

latin_medical_terms: List of Latin medical and pharmaceutical abbreviations

Description

A named character vector. Names represent Latin terms and values the English translations. Used for converting terms like "q4h" into "every 4 hours", which can then be parsed into a dosage frequency/interval.

Usage

latin_medical_terms

Arguments

Format

An object of class character of length 47.

Details

Use with a function like str_replace_all to translate a prescription from Latin to English (thence to numbers).

Examples

Run this code
# NOT RUN {
stringr::str_replace_all('Take two tablets q4h', latin_medical_terms)

# }

Run the code above in your browser using DataLab