Learn R Programming

doseminer (version 0.1.2)

words2number: Convert English names of numbers to their numerical values

Description

Convert English names of numbers to their numerical values

Usage

words2number(txt)

Arguments

txt

A character vector containing names of numbers (only).

Value

A named numeric vector of the same length as phrase.

Examples

Run this code
# NOT RUN {
words2number('seven')
words2number('forty-two')
words2number(c('three', 'one', 'twenty two thousand'))

# }

Run the code above in your browser using DataLab