powered by
Convert English names of numbers to their numerical values
words2number(txt)
A character vector containing names of numbers (only).
A named numeric vector of the same length as phrase.
phrase
# NOT RUN { words2number('seven') words2number('forty-two') words2number(c('three', 'one', 'twenty two thousand')) # }
Run the code above in your browser using DataLab